import { Server } from 'socket.io'
import { TSocket } from '../../utilities/Types'
import CharacterRepository from '../../repositories/CharacterRepository'
import ZoneRepository from '../../repositories/ZoneRepository'

type TypePayload = {
  message: string
}

export default function (socket: TSocket, io: Server) {
  socket.on('chat:send_message', async (data: TypePayload, callback: (response: boolean) => void) => {
    console.log(`---User ${socket.character?.id} has sent a message via chat.`)

    if (!data.message) {
      console.log(`---Message not provided.`)
      return
    }

    try {
      const character = await CharacterRepository.getByUserAndId(socket.user?.id as number, socket.character?.id as number)
      if (!character) {
        console.log(`---Character not found.`)
        return
      }

      const zone = await ZoneRepository.getById(character.zoneId)
      if (!zone) {
        console.log(`---Zone not found.`)
        return
      }

      // send over zone and characters to socket
      callback(true)
      io.to(zone.id.toString()).emit('chat:message', {
        character: character,
        message: data.message
      })
    } catch (error: any) {
      console.log(`---Error sending message: ${error.message}`)
    }
  })
}
